@@ -42,7 +42,7 @@ def default_pipe_logger(self):
             self.logger.info("%s", line.decode())
         if not r:
             self.logger.info("%s", lines.decode())
-            self.logger.error("PIPE CLOSED -- Asuming process has terminated")
+            self.logger.error("PIPE CLOSED -- Assuming process has terminated")
             return
 
 
